# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

#TODO: Add BR: perl(Test::Pod::Spelling::CommonMistakes) when available
#TODO: Add BR: perl(DBD::AnyData) >= 0.110 when available
#TODO: Add BR: perl(DBD::DBM) >= 0.06 when available
#TODO: Add BR:/R: perl(SQL::UserDefs) when available

Name:		perl-SQL-Statement
Version:	1.414
Release:	10.%{__distinit}%{__distvers}
Summary:	SQL parsing and processing engine
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/SQL-Statement
Source0:	https://cpan.metacpan.org/authors/id/R/RE/REHSACK/SQL-Statement-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Clone) >= 0.30
BuildRequires:	perl(constant)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Math::Base::Convert)
BuildRequires:	perl(Math::Trig)
BuildRequires:	perl(Module::Runtime)
BuildRequires:	perl(Params::Util) >= 1.00
BuildRequires:	perl(Scalar::Util) >= 1.0
BuildRequires:	perl(sort)
BuildRequires:	perl(strict)
BuildRequires:	perl(Text::Balanced)
BuildRequires:	perl(Text::Soundex)
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Cwd)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::Deep)
BuildRequires:	perl(Test::More) >= 0.88
# Optional Tests
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(DBD::CSV) >= 0.30
%endif
BuildRequires:	perl(DBD::File) >= 0.40
BuildRequires:	perl(DBD::SQLite)
BuildRequires:	perl(MLDBM)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Math::Base::Convert)
Requires:	perl(Text::Soundex)

%description
The SQL::Statement module implements a pure Perl SQL parsing and execution
engine. While it by no means implements full ANSI standard, it does support
many features including column and table aliases, built-in and user-defined
functions, implicit and explicit joins, complexly nested search conditions, and
other features.

%prep
%setup -q -n SQL-Statement-%{version}
chmod -c -x Changes README \
	lib/SQL/Eval.pm \
	lib/SQL/Statement.pm \
	lib/SQL/Dialects/ANSI.pm \
	lib/SQL/Dialects/AnyData.pm \
	lib/SQL/Dialects/CSV.pm \
	lib/SQL/Statement/GetInfo.pm \
	lib/SQL/Statement/RAM.pm \
	lib/SQL/Statement/Util.pm
perl -pi -e 's/\r\n/\n/' README

%build
export SQL_STATEMENT_WARN_UPDATE=sure
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license ARTISTIC-1.0 GPL-1 GPL-2.0 LICENSE
%doc Changes README README.md
%{perl_vendorlib}/SQL/
%{_mandir}/man3/SQL::Dialects::ANSI.3*
%{_mandir}/man3/SQL::Dialects::AnyData.3*
%{_mandir}/man3/SQL::Dialects::CSV.3*
%{_mandir}/man3/SQL::Dialects::Role.3*
%{_mandir}/man3/SQL::Eval.3*
%{_mandir}/man3/SQL::Parser.3*
%{_mandir}/man3/SQL::Statement.3*
%{_mandir}/man3/SQL::Statement::Embed.3*
%{_mandir}/man3/SQL::Statement::Function.3*
%{_mandir}/man3/SQL::Statement::Functions.3*
%{_mandir}/man3/SQL::Statement::GetInfo.3*
%{_mandir}/man3/SQL::Statement::Operation.3*
%{_mandir}/man3/SQL::Statement::Placeholder.3*
%{_mandir}/man3/SQL::Statement::RAM.3*
%{_mandir}/man3/SQL::Statement::Roadmap.3*
%{_mandir}/man3/SQL::Statement::Structure.3*
%{_mandir}/man3/SQL::Statement::Syntax.3*
%{_mandir}/man3/SQL::Statement::Term.3*
%{_mandir}/man3/SQL::Statement::TermFactory.3*
%{_mandir}/man3/SQL::Statement::Util.3*

%changelog
* Thu Jul  6 2023 Paul Howarth <paul@city-fan.org> - 1.414-10
- Use SPDX-format license tag
- Use %%license unconditionally

* Wed Oct 21 2020 Paul Howarth <paul@city-fan.org> - 1.414-1
- Update to 1.414
  - Spell check
  - Be specific in which files to skip from the distribution
  - Author fixes
  - Makefile.PL: port WriteMakefile1 from Hash::Merge
  - .travis.yml: update for Xenial VMs
  - Clean up MANIFEST.SKIP
  - Bump copyright year
  - Have SQL::Parser correctly parse VALUES and SET clauses containing
    function invocations with several arguments

* Sat Jun  8 2019 Paul Howarth <paul@city-fan.org> - 1.412-11
- Perl 5.30 rebuild

* Fri Apr 13 2018 Paul Howarth <paul@city-fan.org> - 1.412-5
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Fri Apr  7 2017 Paul Howarth <paul@city-fan.org> - 1.412-1
- Update to 1.412
  - NumericEval: Fix typo on error handling
    (http://www.perlmonks.org/?node_id=1167381)
  - Fix repo URL and t/02execute.t
  - Fix test failing with blead-perl
  - Refactor constraints processing
  - Support parsing of complex JOIN clause (containing OR and ()'s)
  - Handle backtick quoting
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop patches for building with Test::More < 0.88

* Mon Sep 26 2016 Paul Howarth <paul@city-fan.org> - 1.410-2
- BR: perl-generators where available

* Tue Apr 12 2016 Paul Howarth <paul@city-fan.org> - 1.410-1
- Update to 1.410
  - Remove unnecessary executable bits (CPAN RT#113625)
  - pod2markdown README.md from lib/SQL/Statement.pm

* Wed Apr  6 2016 Paul Howarth <paul@city-fan.org> - 1.409-1
- Update to 1.409
  - Fix CPAN RT#112530: t/06virtual.t fails with -Duselongdouble
  - Fix CPAN RT#105852: dependency installation isn't triggered properly in
    CPAN
  - Fix CPAN RT#99349: bind variables are not bound to placeholders in the
    correct order
  - Update Copyright statements, add where missing (according to records)
  - Add license conditions where missing
  - Bundle copy of license conditions to distribution
- Ship license texts
- Simplify find command using -delete
- Drop trig patch, no longer seems to be needed
- Update patches as needed

* Sun Jun 28 2015 Paul Howarth <paul@city-fan.org> - 1.407-4
- Perl 5.22 rebuild

* Tue May 26 2015 Paul Howarth <paul@city-fan.org> - 1.407-1
- Update to 1.407
  - Fix SQL function CONV to use limited number of sane character sets for
    conversion and rely on Math::Base::Convert instead of own code
    (CPAN RT#100551)
  - Fix handling of literal identifiers and for every IMPORT rely on literal
    identifiers to avoid parser errors for column names starting with numbers
    or similar
  - Fix capability cache: "$class->can(...)" might return undef and therefore
    non-existent capabilities are queried too often
  - Fix COUNT(DISTINCT col) without GROUP BY clause
  - Fix "parse insert with functions" (GitHub PR#6, CPAN RT#96628)
  - Fix CPAN RT#93320: SQL-style comment can not begin inside quotes
  - Fix CPAN RT#104579: Redundant argument in sprintf
  - Fix CPAN RT#104589: t/14parse.t fails if Test::Deep is not installed
  - Clean up Makefile.PL, meta-data and requirements
  - Reduce blocks and rewrite some inner statements to increase speed of sql
    command processing
- Classify buildreqs by usage
- Update patches as needed

* Mon Sep 15 2014 Paul Howarth <paul@city-fan.org> - 1.405-8
- Drop support for old distributions prior to FC-5

* Wed Jul 24 2013 Paul Howarth <paul@city-fan.org> - 1.405-2
- Perl 5.18 rebuild

* Mon Jun 17 2013 Paul Howarth <paul@city-fan.org> - 1.405-1
- Update to 1.405
  - INSERT now expands incomplete rows

* Thu May 23 2013 Paul Howarth <paul@city-fan.org> - 1.404-1
- Update to 1.404
  - Re-enable cleanup test_output* after test done
  - Recommend Text::Soundex and do soundex-test only when we have it, because
    it's going to be removed from core for Perl 5.19

* Thu May 23 2013 Paul Howarth <paul@city-fan.org> - 1.403-1
- Update to 1.403
  - Fix documentation (CPAN RT#84889, CPAN RT#85257)

* Wed Dec 19 2012 Paul Howarth <paul@city-fan.org> - 1.402-1
- Update to 1.402
  - Add Math::Complex 1.56 as recommendation (CPAN RT#81926)
  - Add Math::BigInt 1.88 as recommendation (CPAN RT#81927)
  - Clarify Test::Simple 0.90 is required for building (CPAN RT#81925)
  - Fix leaking reference to open tables outside SQL::Statement::execute
    (fixes CPAN RT#81523)
  - looks_like_number identifies 'nan' as number sometimes (add regex to
    t/06virtual.t)

* Mon Oct 29 2012 Paul Howarth <paul@city-fan.org> - 1.401-1
- Update to 1.401
  - Switch to 3-digited minor version
  - Undo literal replaces in subqueries before passing them to the child parser
  - Fix doc typos (CPAN RT#71914, CPAN RT#76764)
  - Fix DROP TABLE behaviour and error detection
  - Improve documentation/tests for multiple JOINs (CPAN RT#69573)
  - Filling in the SQL92 gaps for functions (CPAN RT#72638)
- BR: perl(Time::HiRes)
- Update patch for old Test::More versions
- Add patch to work around trig test issues on old perls
- Add patch to avoid "Can't use string as a hashref" errors in tests on older
  perls
- Add patch to avoid division by zero in csch and coth on older perls

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1.33-8
- Perl 5.16 post-bootstrap rebuild

* Sun Jul 15 2012 Paul Howarth <paul@city-fan.org> - 1.33-7
- BR:/R: perl(Text::Soundex)
- BR: perl(base), perl(constant), perl(Cwd), perl(Exporter), perl(File::Path),
  perl(File::Spec), perl(lib) and perl(Test::More)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jul  6 2011 Paul Howarth <paul@city-fan.org> - 1.33-2
- Rebuild for perl 5.14.1 in Rawhide
- Add support for perl_bootstrap macro
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Sun Feb  6 2011 Paul Howarth <paul@city-fan.org> - 1.33-1
- Update to 1.33:
  - Move test dependencies to (unreleased) Bundle::Test::SQL::Statement to
    avoid circular dependencies

* Wed Jan 19 2011 Paul Howarth <paul@city-fan.org> - 1.32-1
- Update to 1.32:
  - Fix invalid check for escaped single quotes
  - Fix unpermitted modification of array source for table creation
    (CREATE TABLE AS IMPORT(?),[[..],[..]])
  - Fix alias used in ORDER BY (CPAN RT#61384)
  - Fix ORDER BY behaviour for multiple sort columns (slower, but guaranteed
    correct)
  - Rename fetch-method into fetch_row (keep fetch() as alias) and add a
    fetch_rows() to fetch all rows at once
  - Different accessors for direction of ORDER BY clause query part and its
    boolean equivalent "desc" (0 or 1, respectively)
  - Add a lot of Pure-Perl DBD's as build dependencies for testing
  - Bump requirement of DBI to 1.616
  - Switch for fully external DBD tests from DBD::XBase to DBD::SQLite
  - Document another limitation (lacking implicit creating temp table during
    processing a query using the same table with different aliases twice)
- Bump perl(DBD::CSV) version requirement to 0.30
- Bump perl(DBD::File) version requirement to 0.40
- Bump perl(DBI::DBD::SqlEngine) version requirement to 0.03
- BR: perl(DBD::SQLite) and perl(MLDBM)
- Update patch for old Test::More versions

* Mon Aug 16 2010 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31:
  - Fix misbehaviour of DELETE/UPDATE for some tables
  - Fix some column identifier splits to respect quoted tables
  - Optimized some core routines between 25% and 50%
- Add patch to fix test suite with Test::More < 0.88

* Tue Aug 10 2010 Paul Howarth <paul@city-fan.org> - 1.30-2
- Add buildreq perl(DBD::CSV) now that SQL::Statement is bootstrapped

* Tue Aug 10 2010 Paul Howarth <paul@city-fan.org> - 1.30-1
- Import from Fedora
- Update to 1.30:
  - SQL::Statement >= 1.28 is expected not to work properly in combination with
	DBI 1.611 and below
  - SQL::Statement::ColumnValue now expects every table to be derived from
	SQL::Eval::Table
  - Introduce new "capability" method for SQL::Statement and SQL::Eval::Table
  - Add capability for "insert_new_row" to allow DBD::DBM to fix PK constrain
	on INSERT statements
  - Performance of IMPORT feature improved (CPAN RT#57322)
  - Expect every table object being derived from SQL::Eval::Table
  - Rewrite DELETE and UPDATE command based on table capabilities
  - Add abstract methods for all methods derived classes must override
	(this means, open_table for SQL::Statement deriveds must be overridden
	and all data access methods of tables - see SQL::Eval::Table for details)
  - Tests are fixed to use TEMP TABLES explicitly when required
  - Check for invalid column names fixed
  - Don't let deprecated parser structures stay alive in SQL::Statement when
	reusing the Parser
  - Method documentation of SQL::Statement and SQL::Eval::Table are improved
  - Add a Roadmap describing future plans for SQL::Statement (in addition to
	DBD::File::Roadmap
  - POD spelling and grammar fixes
  - Add some getters as documented in SQL::Statement::Structure (CPAN RT#59834)
  - Add missing import of function croak to SQL::Statement::Term::ColumnValue
  - Fix assignment of parser result (doesn't run with perl 5.13.3)

* Tue Jun  8 2010 Petr Pisar <ppisar@redhat.com> - 1.27-1
- 1.27 bump (do not backport, 1.22 lower-cases unquoted identifiers)
- Make tests fatal again

* Thu May 06 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.20-3
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.20-2
- Rebuild against perl 5.10.1

* Wed Sep 23 2009 Stepan Kasal <skasal@redhat.com> - 1.20-1
- New upstream version

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.15-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.15-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.15-4
- Rebuild for perl 5.10 (again)

* Mon Jan 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.15-3
- Rebuild for new perl

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.15-2.2
- Add BR: perl(Test::More)

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.15-2.1
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Thu Sep  7 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.15-2
- Rebuild for FC6

* Fri Feb 24 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.15-1
- Update to 1.15

* Mon Feb 20 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.14-2
- Rebuild for FC5 (perl 5.8.8)

* Sun Sep 11 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.14-1
- First build
